==> openshift-model-config-6.8.1-sources.jar: io/fabric8/openshift/api/model/config/v1/IngressPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IngressPlatformSpecFluent<A extends IngressPlatformSpecFluent<A>> extends BaseFluent<A>{
  public IngressPlatformSpecFluent() {
  }
  public IngressPlatformSpecFluent(IngressPlatformSpec instance) {
    instance = (instance != null ? instance : new IngressPlatformSpec());

    if (instance != null) {
      this.withAws(instance.getAws());
      this.withType(instance.getType());
      this.withAws(instance.getAws());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private AWSIngressSpecBuilder aws;
  private String type;
  private Map<String,Object> additionalProperties;
  public AWSIngressSpec buildAws() {
    return this.aws!=null ?this.aws.build():null;
  }
  public A withAws(AWSIngressSpec aws) {
    _visitables.get("aws").remove(this.aws);
    if (aws!=null){ this.aws= new AWSIngressSpecBuilder(aws); _visitables.get("aws").add(this.aws);} else { this.aws = null; _visitables.get("aws").remove(this.aws); } return (A) this;
  }
  public boolean hasAws() {
    return this.aws != null;
  }
  public A withNewAws(String type) {
    return (A)withAws(new AWSIngressSpec(type));
  }
  public AwsNested<A> withNewAws() {
    return new AwsNested(null);
  }
  public AwsNested<A> withNewAwsLike(AWSIngressSpec item) {
    return new AwsNested(item);
  }
  public AwsNested<A> editAws() {
    return withNewAwsLike(java.util.Optional.ofNullable(buildAws()).orElse(null));
  }
  public AwsNested<A> editOrNewAws() {
    return withNewAwsLike(java.util.Optional.ofNullable(buildAws()).orElse(new AWSIngressSpecBuilder().build()));
  }
  public AwsNested<A> editOrNewAwsLike(AWSIngressSpec item) {
    return withNewAwsLike(java.util.Optional.ofNullable(buildAws()).orElse(item));
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressPlatformSpecFluent that = (IngressPlatformSpecFluent) o;
    if (!java.util.Objects.equals(aws, that.aws)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(aws,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (aws != null) { sb.append("aws:"); sb.append(aws + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AwsNested<N> extends AWSIngressSpecFluent<AwsNested<N>> implements Nested<N>{
    AwsNested(AWSIngressSpec item) {
      this.builder = new AWSIngressSpecBuilder(this, item);
    }
    AWSIngressSpecBuilder builder;
    public N and() {
      return (N) IngressPlatformSpecFluent.this.withAws(builder.build());
    }
    public N endAws() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/IngressPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IngressPlatformSpecFluent<A extends IngressPlatformSpecFluent<A>> extends BaseFluent<A>{
  public IngressPlatformSpecFluent() {
  }
  
  public IngressPlatformSpecFluent(IngressPlatformSpec instance) {
    this.copyInstance(instance);
  }
  private AWSIngressSpecBuilder aws;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(IngressPlatformSpec instance) {
    instance = (instance != null ? instance : new IngressPlatformSpec());
  
    if (instance != null) {
        this.withAws(instance.getAws());
        this.withType(instance.getType());
        this.withAws(instance.getAws());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public AWSIngressSpec buildAws() {
    return this.aws!=null ?this.aws.build():null;
  }
  
  public A withAws(AWSIngressSpec aws) {
    _visitables.get("aws").remove(this.aws);
    if (aws!=null){ this.aws= new AWSIngressSpecBuilder(aws); _visitables.get("aws").add(this.aws);} else { this.aws = null; _visitables.get("aws").remove(this.aws); } return (A) this;
  }
  
  public boolean hasAws() {
    return this.aws != null;
  }
  
  public A withNewAws(String type) {
    return (A)withAws(new AWSIngressSpec(type));
  }
  
  public AwsNested<A> withNewAws() {
    return new AwsNested(null);
  }
  
  public AwsNested<A> withNewAwsLike(AWSIngressSpec item) {
    return new AwsNested(item);
  }
  
  public AwsNested<A> editAws() {
    return withNewAwsLike(java.util.Optional.ofNullable(buildAws()).orElse(null));
  }
  
  public AwsNested<A> editOrNewAws() {
    return withNewAwsLike(java.util.Optional.ofNullable(buildAws()).orElse(new AWSIngressSpecBuilder().build()));
  }
  
  public AwsNested<A> editOrNewAwsLike(AWSIngressSpec item) {
    return withNewAwsLike(java.util.Optional.ofNullable(buildAws()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressPlatformSpecFluent that = (IngressPlatformSpecFluent) o;
    if (!java.util.Objects.equals(aws, that.aws)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(aws,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (aws != null) { sb.append("aws:"); sb.append(aws + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AwsNested<N> extends AWSIngressSpecFluent<AwsNested<N>> implements Nested<N>{
    AwsNested(AWSIngressSpec item) {
      this.builder = new AWSIngressSpecBuilder(this, item);
    }
    AWSIngressSpecBuilder builder;
    
    public N and() {
      return (N) IngressPlatformSpecFluent.this.withAws(builder.build());
    }
    
    public N endAws() {
      return and();
    }
    
  
  }

}
